(sec_citation)=

# Citing tsbrowse

If you use `tsbrowse` in your work, please cite the
[2025 Bioinformatics paper](<https://doi.org/10.1093/bioinformatics/btaf393>)


> Karthikeyan S, Jeffery B, Mbuli-Robertson D, Kelleher J.
> *Tsbrowse: an interactive browser for ancestral recombination graphs*.
> Bioinformatics. 2025 Aug;41(8):btaf393.

Bibtex record:

```bibtex
@article{karthikeyan2025tsbrowse,
  title={Tsbrowse: an interactive browser for ancestral recombination graphs},
  author={Karthikeyan, Savita and Jeffery, Ben and Mbuli-Robertson, Duncan and Kelleher, Jerome},
  journal={Bioinformatics},
  volume={41},
  number={8},
  pages={btaf393},
  year={2025},
  publisher={Oxford University Press}
}
```
